'use strict';

exports.__esModule = true;
exports.client = exports.lock = exports.authIsRequired = exports.setAuth0User = undefined;

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

exports.refreshUser = refreshUser;

var _auth0Lock = require('auth0-lock');

var _auth0Lock2 = _interopRequireDefault(_auth0Lock);

var _auth0Js = require('auth0-js');

var _auth0Js2 = _interopRequireDefault(_auth0Js);

var _reactRouterRedux = require('react-router-redux');

var _reduxActions = require('redux-actions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _process$env = process.env,
    AUTH0_CLIENT_ID = _process$env.AUTH0_CLIENT_ID,
    AUTH0_DOMAIN = _process$env.AUTH0_DOMAIN;

var localStorage = window.localStorage;

var setAuth0User = exports.setAuth0User = (0, _reduxActions.createAction)('set auth0 user');
var authIsRequired = exports.authIsRequired = AUTH0_CLIENT_ID && AUTH0_DOMAIN;
var lock = exports.lock = authIsRequired ? new _auth0Lock2.default(AUTH0_CLIENT_ID, AUTH0_DOMAIN, {
  auth: {
    params: {
      scope: 'openid analyst offline_access'
    },
    redirect: false
  },
  closeable: false,
  autoclose: true
}) : null;
var client = exports.client = authIsRequired ? new _auth0Js2.default({
  clientID: AUTH0_CLIENT_ID,
  domain: AUTH0_DOMAIN
}) : null;

/**
 * Use on application mount when authentication is required
 */
function refreshUser(dispatch) {
  if (authIsRequired) {
    (function () {
      var userString = localStorage.getItem('user');
      var user = userString && JSON.parse(userString);
      if (user && user.refreshToken) {
        dispatch(setAuth0User(user));
        if (process.env.NODE_ENV !== 'development') {
          client.refreshToken(user.refreshToken, function (err, delegationResult) {
            if (err) {
              dispatch(setAuth0User(null));
              localStorage.setItem('user', null);
              dispatch((0, _reactRouterRedux.push)('/login'));
            } else {
              user.idToken = delegationResult.id_token;
              dispatch(setAuth0User(user));
              localStorage.setItem('user', (0, _stringify2.default)(user));
            }
          });
        }
      } else {
        dispatch((0, _reactRouterRedux.push)('/login'));
      }
    })();
  }
}

//# sourceMappingURL=auth0.js