'use strict';

exports.__esModule = true;
exports.fetchAction = exports.fetchError = exports.decrementFetches = exports.incrementFetches = exports.FETCH_ERROR = exports.FETCH = exports.DECREMENT_FETCH = exports.INCREMENT_FETCH = undefined;

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var createResponse = function () {
  var _ref2 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(res) {
    var value;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return deserialize(res);

          case 3:
            value = _context.sent;
            return _context.abrupt('return', {
              url: res.url,
              status: res.status,
              statusText: res.statusText,
              headers: res.headers,
              value: value
            });

          case 7:
            _context.prev = 7;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', {
              value: _context.t0
            });

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this, [[0, 7]]);
  }));

  return function createResponse(_x) {
    return _ref2.apply(this, arguments);
  };
}();

exports.middleware = middleware;

var _isomorphicFetch = require('isomorphic-fetch');

var _isomorphicFetch2 = _interopRequireDefault(_isomorphicFetch);

var _lodash = require('lodash.isobject');

var _lodash2 = _interopRequireDefault(_lodash);

var _reduxActions = require('redux-actions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var INCREMENT_FETCH = exports.INCREMENT_FETCH = 'increment outstanding fetches';
var DECREMENT_FETCH = exports.DECREMENT_FETCH = 'decrement outstanding fetches';
var FETCH = exports.FETCH = 'fetch';
var FETCH_ERROR = exports.FETCH_ERROR = 'fetch error';

var incrementFetches = exports.incrementFetches = (0, _reduxActions.createAction)(INCREMENT_FETCH);
var decrementFetches = exports.decrementFetches = (0, _reduxActions.createAction)(DECREMENT_FETCH);
var fetchError = exports.fetchError = (0, _reduxActions.createAction)(FETCH_ERROR);
var fetchAction = exports.fetchAction = (0, _reduxActions.createAction)(FETCH);

function middleware(store) {
  return function (next) {
    return function (action) {
      return action.type === FETCH ? store.dispatch(incrementFetches()) && store.dispatch(runFetch(action.payload, store.getState())) : next(action);
    };
  };
}

exports.default = fetchAction;

/**
 * Calls fetch, adds Auth and Content header if needed. Automatically parses content based on type.
 *
 * @returns Promise
 */

function runFetch(_ref, state) {
  var next = _ref.next,
      _ref$options = _ref.options,
      options = _ref$options === undefined ? {} : _ref$options,
      url = _ref.url;

  var isJSON = (0, _lodash2.default)(options.body);
  return (0, _isomorphicFetch2.default)(url, (0, _extends3.default)({}, options, {
    body: isJSON ? (0, _stringify2.default)(options.body) : options.body,
    headers: (0, _extends3.default)({}, createAuthorizationHeader(state), createContentHeader(isJSON), options.headers || {})
  })).then(checkStatus).then(createResponse).then(function (response) {
    return [decrementFetches(), next(response)];
  }).catch(function (error) {
    return createErrorResponse(error).then(function (response) {
      return [decrementFetches(), fetchError(response), next(response, true)];
    });
  });
}

function createAuthorizationHeader(state) {
  return state.user && state.user.idToken ? { Authorization: 'bearer ' + state.user.idToken } : {};
}

function checkStatus(res) {
  if (res.status >= 200 && res.status < 300) {
    return res;
  } else {
    throw res;
  }
}

function createContentHeader(isJSON) {
  return isJSON ? { 'Accept': 'application/json', 'Content-Type': 'application/json;charset=UTF-8' } : {};
}

function createErrorResponse(res) {
  return res.headers ? createResponse(res) : _promise2.default.resolve(res);
}

function deserialize(res) {
  var header = [res.headers.get('Content-Type'), res.headers.get('Content')].filter(Boolean);
  if (header.indexOf('application/json') > -1) return res.json();
  if (header.indexOf('application/ld+json') > -1) return res.json();
  if (header.indexOf('application/octet-stream') > -1) return res.arrayBuffer();
  return res.text();
}

//# sourceMappingURL=fetch.js